function [Nc] = eulero_contagi(Nc0,P,C,t0,T,N)
%---------------------------------------
% Risolve l'ODE Nc'(t)=funz(t) con il metodo di Eulero "in avanti"
% per il caso funz(t)= C Nc(1-Nc/P), con grafici per diversi modelli per C
%---------------------------------------
h = (T-t0)/N;       % passo di discretizzazione
t = t0:h:T;         % vettore dei tempi
%fprintf('\n \t T: %2.2f \t P: %5.5f \t C: %2.2f \n',T,P,C);

C0 = 0.20;  % tasso di contagio di riferimento

Nc(1) = Nc0; deltaNc(1) = 0.;  % esponenziale
for n=1:N
  funz(n)= C0.*Nc(n);
  Nc(n+1) = Nc(n) + h*funz(n);
  deltaNc(n+1) = h*funz(n);  
endfor
z0 = Nc/P;     % frazione di infetti
y0 = deltaNc;  % nuovi infetti ogni giorno

Nc(1) = Nc0; deltaNc(1) = 0.;  % equazione logistica, C costante
for n=1:N
  funz(n)=C0.*Nc(n).*(1-Nc(n)/P);
  Nc(n+1) = Nc(n) + h*funz(n);
  deltaNc(n+1) = h*funz(n);  
endfor
z1 = Nc/P;     % frazione di infetti
y1 = deltaNc;  % nuovi infetti ogni giorno

Nc(1) = Nc0; deltaNc(1) = 0.;  % equazione logistica, C descresce linearmente
for n=1:N
  C = C0*(1.-n/N);
  funz(n)=C.*Nc(n).*(1-Nc(n)/P);
  Nc(n+1) = Nc(n) + h*funz(n);
  deltaNc(n+1) = h*funz(n);  
endfor
z2 = Nc/P;     % frazione di infetti
y2 = deltaNc;  % nuovi infetti ogni giorno

Nc(1) = Nc0; deltaNc(1) = 0.; % equazione logistica, C descresce quadraticamente
for n=1:N
  C = C0*(1.-n/N)^2;
  funz(n)=C.*Nc(n).*(1-Nc(n)/P);
  Nc(n+1) = Nc(n) + h*funz(n);
  deltaNc(n+1) = h*funz(n);  
endfor
z3 = Nc/P;     % frazione di infetti
y3 = deltaNc;  % nuovi infetti ogni giorno

Nc(1) = Nc0; deltaNc(1) = 0.; % equazione logistica, da C a C/10 in pochi step
for n=1:25 
  funz(n)=C0.*Nc(n).*(1-Nc(n)/P);
  Nc(n+1) = Nc(n) + h*funz(n);
  deltaNc(n+1) = h*funz(n);  
endfor
for n=26:33
  C = C0*(1.-0.1*(n-25));
  funz(n)=C.*Nc(n).*(1-Nc(n)/P);
  Nc(n+1) = Nc(n) + h*funz(n);
  deltaNc(n+1) = h*funz(n);  
endfor
for n=34:N 
  C = C0/10.;
  funz(n)=C.*Nc(n).*(1-Nc(n)/P);
  Nc(n+1) = Nc(n) + h*funz(n);
  deltaNc(n+1) = h*funz(n);  
endfor
z4 = Nc/P      % frazione di infetti
y4 = deltaNc;  % nuovi infetti ogni giorno

figure;               % A: evoluzione nel tempo della frazione di infetti
plot(t,z1,'Linewidth',2, t,z0,'b--','Linewidth',2);
legend('equazione logistica','esponenziale');
title({"modelli per la diffusione di un contagio in una popolazione"});
xlabel('giorni'); ylabel('Nc/P (frazione della popolazione contagiata)'); axis ([0,90,0,1.2,]);

figure;               % B: evoluzione nel tempo del numero di nuovi infetti
plot(t,y1,'Linewidth',2, t,y0,'b--','Linewidth',2);
legend('equazione logistica','esponenziale');
title({"modelli per la diffusione di un contagio in una popolazione"});
xlabel('giorni'); ylabel('numero di nuovi contagi al giorno'); axis ([0,90,0,5.5*10^3,]);

figure;               % C: evoluzione nel tempo della frazione di infetti
plot(t,z1,'Linewidth',2, t,z2,'Linewidth',2, t,z4,'Linewidth',2);
legend('C costante','C cala linearmente nel tempo','C ridotto a 1/10 dopo 30 giorni');
title({"modelli per la diffusione di un contagio in una popolazione"});
xlabel('giorni'); ylabel('Nc/P (frazione della popolazione contagiata)'); axis ([0,90,0,1.2,]);

figure;               % D: evoluzione nel tempo del numero di nuovi infetti
plot(t,y1,'Linewidth',2, t,y2,'Linewidth',2, t,y4,'Linewidth',2);
legend('C costante','C cala linearmente nel tempo','C ridotto a 1/10 dopo 30 giorni');
title({"modelli per la diffusione di un contagio in una popolazione"});
xlabel('giorni'); ylabel('numero di nuovi contagi al giorno'); axis ([0,90,0,5.5*10^3,]);

endfunction